summaryrefslogtreecommitdiff
path: root/share
diff options
context:
space:
mode:
Diffstat (limited to 'share')
-rw-r--r--share/spack/qa/flake8_formatter.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/share/spack/qa/flake8_formatter.py b/share/spack/qa/flake8_formatter.py
index 0611d54019..523ee7b4d0 100644
--- a/share/spack/qa/flake8_formatter.py
+++ b/share/spack/qa/flake8_formatter.py
@@ -16,10 +16,10 @@ from flake8.style_guide import Violation
pattern_exemptions = {
# exemptions applied only to package.py files.
r"package.py$": {
# Allow 'from spack import *' in packages, but no other wildcards
"F403": [
- r"^from spack import \*$",
- r"^from spack.pkgkit import \*$",
+ r"^from spack.package import \*$",
+ r"^from spack.package_defs import \*$",
],
# Exempt lines with urls and descriptions from overlong line errors.
"E501": [
@@ -16,10 +16,10 @@ from flake8.style_guide import Violation
# exemptions applied only to package.py files.
r"package.py$": {
- # Allow 'from spack import *' in packages, but no other wildcards
+ # Allow 'from spack.package import *' in packages, but no other wildcards
"F403": [